[![CI](https://github.com/apatlpo/pynsitu/actions/workflows/ci.yaml/badge.svg)](https://github.com/apatlpo/pynsitu/actions/workflows/ci.yaml)
[![code-style](https://github.com/apatlpo/pynsitu/actions/workflows/linting.yaml/badge.svg)](https://github.com/apatlpo/pynsitu/actions/workflows/linting.yaml)
[![Check and Maybe Release Python Package](https://github.com/apatlpo/pynsitu/actions/workflows/release.yaml/badge.svg)](https://github.com/apatlpo/pynsitu/actions/workflows/release.yaml)
[![Documentation](https://readthedocs.org/projects/pynsitu/badge/?version=latest)](https://pynsitu.readthedocs.io/en/latest/?badge=latest)

# pynsitu: oceanographic insitu data toolbox

Various tools for the processing of oceanographic data based on pandas/xarray.
See [documention](https://pynsitu.readthedocs.io/en/latest/index.html)
